@@ -1,53 +1,50 @@
 import numpy as np
 import os
 import math
-#from .database import *
-from .full_model import generate_full
+from .full_model import *
 from .utils import *
 from .mfp2DSym import *
+from .mg2DSym import *
 from .mfp2D import *
 from .mfp3D import *
 from .gray2D import *
+from .gray2DSym import *
 from .rta2DSym import *
 from .rta3D import *
 from mpi4py import MPI
 import shutil
-import pickle
-import lzma
-import gzip
-import bz2
-#import BytesIO
-
 
 comm = MPI.COMM_WORLD
 
-class Material(object):
+def Material(**argv):
 
- def __init__(self,**argv):
-
-   save = argv.setdefault('save',True)
    model = argv['model']
+
+   #set up database
    source = argv.setdefault('source','local')
    if source == 'database':
     if comm.rank == 0:
-        basename = os.path.dirname(os.path.dirname(os.path.realpath(__file__))) + \
-                  '/openbte/materials/' + model[:3] + '_' +  argv['filename'] + \
+        filename = os.path.dirname(os.path.dirname(os.path.realpath(__file__))) + \
+                  '/openbte/materials/rta_' +  argv['filename'] + \
                   '_' + str(argv['temperature']) 
 
-        argv['basename'] = basename
+        argv['filename'] = filename
 
-        #shutil.copyfile(filename,os.getcwd() + '/' + model[:3] +'.npz')
    if source == 'unlisted':
     if comm.rank == 0:
       download_file(argv['file_id'],'rta.npz')
 
-   if model == 'full':
+   if model == 'rta2DSym':
      if comm.rank == 0:
-      data = generate_full(**argv)
+      data = rta2DSym(**argv)
+
+   elif model == 'full':
+     if comm.rank == 0:
+      data = full(**argv)
 
    elif model == 'mfp2DSym':
-      data = generate_mfp2DSym(**argv)
-   
+      data = mfp2DSym(**argv)
+
    elif model == 'fourier':
       
       kappa = np.eye(3)
@@ -60,31 +57,41 @@ class Material(object):
       data = {'kappa':kappa,'model':[0]}
 
    elif model == 'mfp2D':
-      data = generate_mfp2D(**argv)
+      data = mfp2D(**argv)
 
    elif model == 'gray2DSym':
-      data = generate_mfp2DSym(**argv)
+      data = gray2DSym(**argv)
+
+   elif model == 'mg2DSym':
+     if comm.rank == 0:
+      data = mg2DSym(**argv)
 
    elif model == 'gray2D':
-      data = generate_gray2D(**argv)
-
-   elif model == 'gray3D':
-      data = generate_mfp3D(**argv)
+      data = gray2D(**argv)
 
+   #elif model == 'gray3D':
+   #   data = mfp3D(**argv)
+   
    elif model == 'mfp3D':
-      data = generate_mfp3D(**argv)
-
-   elif model == 'rta2DSym':
-     if comm.rank == 0:
-      data = generate_rta2DSym(**argv)
+      data = mfp3D(**argv)
 
    elif model == 'rta3D':
      if comm.rank == 0:
-      data = generate_rta3D(**argv)
+      data = rta3D(**argv)
 
-   if save :
+   else:   
+      print('No model recognized')
+      quit()
+
+
+   if argv.setdefault('save',True):
      if comm.rank == 0:
          save_data(argv.setdefault('output_filename','material'),data)   
-   else:
-     if comm.rank == 0:
-      self.state = data
+
+   if comm.rank == 0:
+    return data
+
+ 
+
+
+
